==> nextcloud-11.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/ru.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "События",
    "Error loading activities" : "Ошибка загрузки событий",
    "No activities" : "Событий нет",
    "Load more activities" : "Загрузить ещё события",
    "Copied!" : "Скопировано!",
    "Not supported!" : "Не поддерживается!",
    "Press ⌘-C to copy." : "Нажмите ⌘-C для копирования. ",
    "Press Ctrl-C to copy." : "Нажмите Ctrl-C для копирования.",
    "{name} (invisible)" : "{имя} (невидимый)",
    "{name} (restricted)" : "{имя} (ограничено)",
    "in {path}" : "в {path}",
    "This stream will show events like additions, changes & shares" : "Этот поток будет отображать события вроде добавления, изменения файлов или открытия доступа к ним",
    "There are no events for this filter" : "Нет событий, соответствующих фильтру",
    "Today" : "Сегодня",
    "Yesterday" : "Вчера",
    "Activity" : "События",
    "Personal activity feed for %s" : "Персональная лента событий для %s",
    "Your feed URL is invalid" : "Ваша ссылка на новостную ленту неправильная",
    "Your settings have been updated." : "Настройки обновлены.",
    "Mail" : "Почта",
    "Stream" : "Поток",
    "All activities" : "Все события",
    "By others" : "Другими",
    "By you" : "Вами",
    "\"remote user\"" : "\"удалённый пользователь\"",
    "Activity notification" : "Уведомление о событиях",
    ", " : ",",
    "%s and %s" : "%s и %s",
    "Hello %s," : "Привет, %s,",
    "You are receiving this email because the following things happened at %s" : "Вы получили это сообщение, потому что произошли следующие события %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* и на %n больше","* и на %n больше","* и на %n больше","* и ещё %n"],
    "List your own actions in the stream" : "Перечислите ваши действия в потоке",
    "Notify about your own actions via email" : "Уведомлять по почте о ваших действиях",
    "You need to set up your email address before you can receive notification emails." : "Для получения уведомлений укажите свой e-mail в настройках.",
    "Send emails:" : "Отправлять электронные сообщения:",
    "Hourly" : "Ежечасно",
    "Daily" : "Ежедневно",
    "Weekly" : "Еженедельно",
    "Activity feed" : "Лента событий",
    "Enable RSS feed" : "Включить RSS ленту",
    "No activity yet" : "Событий ещё нет",
    "No more events to load" : "Больше нет событий для загрузки",
    "Files" : "Файлы"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> nextcloud-12.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/ru.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "События",
    "An error occurred while loading activities" : "Во время загрузки списка событий возникла ошибка",
    "No activity yet" : "Событий ещё нет",
    "Load more activities" : "Загрузить ещё события",
    "Copied!" : "Скопировано!",
    "Not supported!" : "Не поддерживается!",
    "Press ⌘-C to copy." : "Нажмите ⌘-C для копирования. ",
    "Press Ctrl-C to copy." : "Нажмите Ctrl-C для копирования.",
    "{name} (invisible)" : "{имя} (невидимый)",
    "{name} (restricted)" : "{имя} (ограничено)",
    "in {path}" : "в {path}",
    "This stream will show events like additions, changes & shares" : "Этот поток будет отображать события вроде добавления, изменения файлов или открытия доступа к ним",
    "There are no events for this filter" : "Нет событий, соответствующих фильтру",
    "Today" : "Сегодня",
    "Yesterday" : "Вчера",
    "Personal activity feed for %s" : "Персональная лента событий для %s",
    "Your feed URL is invalid" : "Ваша ссылка на ленту неправильная",
    "Your settings have been updated." : "Настройки обновлены.",
    "Settings have been updated." : "Настройки обновлены.",
    "Mail" : "Почта",
    "Stream" : "Поток",
    "All activities" : "Все события",
    "By others" : "Других",
    "By you" : "Ваши",
    "\"remote user\"" : "\"удалённый пользователь\"",
    "Hello %s" : "Привет, %s",
    "Hello %s," : "Привет, %s,",
    "There was some activity at %s" : "Что-то произошло в %s",
    "_and %n more _::_and %n more _" : ["и ещё %n","и ещё %n","и ещё %n","и ещё %n"],
    "Activity notification" : "Уведомление о событиях",
    ", " : ",",
    "%s and %s" : "%s и %s",
    "Activity" : "Событие",
    "Activity feed" : "Лента событий",
    "Configure the default activity settings for new users." : "Задать настройки по умолчанию для событий для новых пользователей.",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Выберите, уведомления о каких событиях отправлять по email, а какие выводить в ленте.",
    "List your own actions in the stream" : "Показывать ваши действия в потоке",
    "Notify about your own actions via email" : "Уведомлять по почте о ваших действиях",
    "You need to set up your email address before you can receive notification emails." : "Для получения уведомлений укажите свой адрес электронной почты в настройках.",
    "Send emails:" : "Отправлять электронные сообщения:",
    "Hourly" : "Ежечасно",
    "Daily" : "Ежедневно",
    "Weekly" : "Еженедельно",
    "Settings" : "Настройки",
    "Enable RSS feed" : "Включить RSS ленту",
    "No more events to load" : "Больше нет событий для загрузки",
    "Files" : "Файлы"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
